@@ -12,6 +12,8 @@ sudo yum -y remove PackageKit gnome-software
 sudo yum -y update
 
 installPackages=()
+# Make sure needed ca-certificates are available
+installPackages+=(ca-certificates)
 installPackages+=(git)
 installPackages+=(zlib-devel)
 installPackages+=(glib2-devel)
@@ -58,8 +60,6 @@ installPackages+=(dbus-devel)
 installPackages+=(gstreamer1-plugins-bad-free)
 installPackages+=(gstreamer1-devel)
 installPackages+=(gstreamer1-plugins-base-devel)
-# pipewire for QtMultimedia
-installPackages+=(pipewire-devel)
 # for QtMultimedia, ffmpeg
 installPackages+=(yasm)
 installPackages+=(libva-devel)
@@ -69,10 +69,14 @@ installPackages+=(gtk3-devel)
 installPackages+=(libusbx-devel)
 # speech-dispatcher-devel for QtSpeech, otherwise it has no backend on Linux
 installPackages+=(speech-dispatcher-devel)
+# Python 2 devel and pip. python-pip requires the EPEL repository to be added
+installPackages+=(python2-devel python2-pip)
+# Python 3 with python-devel, pip and virtualenv
+installPackages+=(python36)
+installPackages+=(python36-devel)
 # Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
-installPackages+=(python3.11)
-installPackages+=(python3.11-pip)
-installPackages+=(python3.11-devel)
+installPackages+=(python38)
+installPackages+=(python38-devel)
 # WebEngine
 installPackages+=(bison)
 installPackages+=(flex)
@@ -80,17 +84,13 @@ installPackages+=(gperftools-libs)
 installPackages+=(gperf)
 installPackages+=(alsa-lib-devel)
 installPackages+=(pulseaudio-libs-devel)
-installPackages+=(libdrm-devel)
-installPackages+=(libva-devel)
 installPackages+=(libXtst-devel)
 installPackages+=(libxshmfence-devel)
 installPackages+=(nspr-devel)
 installPackages+=(nss-devel)
 installPackages+=(python3-html5lib)
-installPackages+=(libatomic)
-installPackages+=(mesa-libgbm-devel-21.3.4-1.el8.x86_64)
 # For Android builds
-installPackages+=(java-17-openjdk-devel-17.0.9.0.9)
+installPackages+=(java-11-openjdk-devel-11.0.19.0.7)
 # For receiving shasum
 installPackages+=(perl-Digest-SHA)
 # INTEGRITY requirements
@@ -105,8 +105,8 @@ installPackages+=(libxslt-devel)
 # For building Wayland from source
 installPackages+=(libffi-devel)
 # QtWayland
-#installPackages+=(mesa-libwayland-egl)
-#installPackages+=(mesa-libwayland-egl-devel)
+installPackages+=(mesa-libwayland-egl)
+installPackages+=(mesa-libwayland-egl-devel)
 installPackages+=(libwayland-client)
 installPackages+=(libwayland-cursor)
 installPackages+=(libwayland-server)
@@ -143,20 +143,11 @@ installPackages+=(gcc-c++)
 installPackages+=(make)
 # Open source VMware Tools
 installPackages+=(open-vm-tools)
-# cifs-utils, for mounting smb drive
-installPackages+=(keyutils)
-installPackages+=(cifs-utils)
-# used for reading vcpkg packages version, from vcpkg.json
-installPackages+=(jq)
-# zip, needed for vcpkg caching
-installPackages+=(zip)
-# OpenSSL requirement, built by vcpkg
-installPackages+=(perl-IPC-Cmd)
-# password management support for Qt Creator
-installPackages+=(libsecret-devel)
 
 sudo yum -y install "${installPackages[@]}"
 
+sudo ln -s /usr/bin/python2 /usr/bin/python
+
 sudo dnf -y module install nodejs:16
 
 # We shouldn't use yum to install virtualenv. The one found from package repo is not
@@ -168,20 +159,13 @@ sudo pip config --user set global.extra-index-url https://pypi.org/simple/
 
 sudo pip3 install virtualenv wheel
 # Just make sure we have virtualenv to run with python3.8 -m virtualenv
-sudo python3.11 -m pip install virtualenv wheel
-sudo python3.11 -m pip install -r "${BASH_SOURCE%/*}/../common/shared/sbom_requirements.txt"
-# For now we don't set QT_SBOM_PYTHON_APPS_PATH here, and rely on the build system to find the
-# system python3.11.
+sudo python3.8 -m pip install virtualenv wheel
 
 sudo /usr/bin/pip3 install wheel
 sudo /usr/bin/pip3 install dataclasses
-# No sbom_requirements.txt, because it requires Python 3.9 for poetry_core -> spdx_tools and we have 3.8
 
 gccVersion="$(gcc --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "GCC = $gccVersion" >> versions.txt
 
 OpenSSLVersion="$(openssl3 version |cut -b 9-14)"
-echo "System's OpenSSL = $OpenSSLVersion" >> ~/versions.txt
-
-# List all available updates
-sudo yum -y list updates
+echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
