@@ -2,4 +2,4 @@
 # Copyright (C) 2024 The Qt Company Ltd
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
-source "${BASH_SOURCE%/*}/../common/unix/install-ffmpeg.sh" "linux" "static"
+source "${BASH_SOURCE%/*}/../common/linux/install-ffmpeg-linux.sh" "static"
